@@ -4,7 +4,8 @@
 #' @param au_id Author ID number
 #' @param api_key API Key for Elsevier
 #' @param http Address for scopus api
-#' @param count number of records to retrieve (below 100)
+#' @param count number of records to retrieve (below 25, see
+#' \url{http://dev.elsevier.com/api_key_settings.html})
 #' @param verbose Print diagnostic messages
 #' @param facets Facets sent in query.  See \url{http://dev.elsevier.com/api_docs.html}
 #' @param searcher Identifer for author ID.  Do not change unless you
@@ -13,12 +14,14 @@
 #' @param ... Arguments to be passed to \code{\link{GET}}
 #' @export
 #' @seealso \code{\link{get_author_info}}
+#' @importFrom httr stop_for_status
+#' @importFrom utils setTxtProgressBar txtProgressBar
 #' @return List of entries from SCOPUS
 author_search <- function(
   au_id, # Author ID number
   api_key = NULL,
   http = "http://api.elsevier.com/content/search/scopus",
-  count = 100, # number of records to retrieve (below 100)
+  count = 25, # number of records to retrieve (below 25)
   verbose = TRUE,
   facets =  "subjarea(sort=fd)",
   searcher = "AU-ID",
@@ -40,6 +43,7 @@ author_search <- function(
             add_headers(
               "X-ELS-ResourceVersion" = "allexpand")
     )
+    stop_for_status(r)
     cr = content(r)$`search-results`
     return(cr)
   }
@@ -69,20 +73,35 @@ author_search <- function(
   ### Loop through all the other pages
   all_entries = cr$entry
   n_runs = ceiling(total_results / count)
-  if (n_runs > 1){
-    for (irun in seq(n_runs - 1)){
+  if (n_runs > 1) {
+    if (verbose) {
+      message(paste0(n_runs, " runs need to be ",
+                     "sent with curent count"))
+      pb = txtProgressBar(min = ifelse(n_runs == 2, 0, 1), max = n_runs - 1,
+                          initial = 1, style = 3)
+    }
+    for (irun in seq(n_runs - 1)) {
       start = irun * count
       cr = get_results(au_id, start = start, count = count,
                        facets = facets)
       all_entries = c(all_entries, cr$entry)
       all_facets = c(all_facets, cr$facet)
+      if (verbose) {
+        if ((irun %% 10) == 0) {
+          # message(paste0("Run #", irun))
+          setTxtProgressBar(pb, value = irun)
+        }
+      }
     }
+   if (verbose) {
+     close(pb)
+   }
   }
-  if (verbose){
+  if (verbose) {
     message(paste0("Number of Output Entries are ", length(all_entries),
                  "\n"))
   }
-  if (total_results != length(all_entries)){
+  if (total_results != length(all_entries)) {
     warning("May not have received all entries")
   }
   return(list(entries = all_entries, facets = all_facets))
